# $Id: JSProfile.pm,v 1.37.4.4 2006/02/01 22:40:43 jb122832 Exp $
# Copyright (c) 2003 Sun Microsystems, Inc. All rights reserved
# SUN PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.

#
# JSProfile API
#
# this extends the Profile.pm to deal with Jumpstart type builds
# vi users
# :set tabstop=4

package JSProfile;
use strict;

use lib "/opt/SUNWscs/lib/perl5";
use lib "/opt/sun/scs/lib/perl5";
use BDUtil;
use Profile;

use vars qw(@ISA);
@ISA = qw(Profile);

sub new
{
    my $proto = shift @_;
    my $class = ref($proto) || $proto;
    my $self  = Profile->new(@_);
    bless($self, $class);

    return $self;
}

# ------------------------------------------------
# This is the a key method in this module
# this write the ksconfig file for a given profile
# Arguments: mac, destination dir
# ------------------------------------------------
sub gen_config
{
	my $self = shift @_;
	my $client = shift @_ || return -1;
	my ($ret, $ver_num);

	$self->{client} = $client;
	$self->{ver_num} = '9';
	$self->{version} = 'Solaris_'.$self->{ver_num};
	#print "client: $client version: $version num_ver: $ver_num\n";

	$ret = $self->gen_sysid();
	if($ret == -1) {
		$self->task_warn("cannotGenSysIdCfg");
		return -1;
	}
	return 1;
}

sub gen_sysid
{
	my $self = shift @_;
	my $client_id = $self->{client}->{client_id};
	my $dir = $cfg->js_dir.'/Profiles/sysid/'.$client_id;
	my $file = $dir."/sysidcfg";
	my ($ret, $out);
	if(!-d $dir) { $cfg->mkdir($dir); }

	$ret = $self->get_option_value('system_locale');
	if($ret && $ret ne -1) {
		$out = "system_locale=".$ret."\n";
	} else { $out = "system_locale=en_US\n"; }

	# pull the as_ip_config table
	$ret = $self->gen_network_sysid();
	if($ret eq -1) { return -1; }
	else { $out .= $ret; };

	$ret = $self->get_option_value('timezone');
	if($ret && $ret ne -1) {
		$out .= "timezone=".$ret."\n";
	} else { $out .= "timezone=US/Central\n"; }

	$ret = $self->get_option_value('terminal');
	if($ret && $ret ne -1) {
		$out .= "terminal=".$ret."\n";
	} else { $out .= "terminal=vt100\n"; }
	
	$ret = $self->get_option_value('timeserver');
	if($ret && $ret ne -1) {
		$out .= "timeserver=".$ret."\n";
	} else { $out .= "timeserver=localhost\n"; }

	$ret = $self->get_name_service();
	if($ret && $ret ne -1) {
		$out .= $ret;
	} else { $out .= "name_service=none\n"; }
	
	$ret = $self->get_option_value('root_passwd_crypt');
	if($ret && $ret ne -1) {
		$out .= "root_password=".$ret."\n";
	} else { return -1; }

	$ret = $self->get_option_value('security_policy');
	if($ret && $ret ne -1) {
		$out .= "security_policy=".$ret."\n";
	} else { $out .= "security_policy=none\n"; }

	$ret = $self->get_option_value('keyboard');
	if($ret && $ret ne -1) {
		$out .= "keyboard=:".$ret." {\n}\n";
	} else { $out .= "keyboard=workaround:Unknown\n"; }

	$ret = $self->get_option_value('xconfig_video_card');
	if($ret && $ret ne -1) {
		$out .= "display=:".$ret." {\n}\n";
	} else { $out .= "display=workaround:Unknown\n"; }

	$ret = $self->get_option_value('mouse');
	if($ret && $ret ne -1) {
		$out .= "pointer=:".$ret." {\n}\n";
	} else { $out .= "pointer=workaround:Unknown\n"; }

	$ret = $self->get_option_value('xconfig_monitor');
	if($ret && $ret ne -1) {
		$out .= "monitor=:".$ret." {\n}\n";
	} else { $out .= "monitor=workaround:Unknown\n"; }

	$ret = $self->write_config_file($file, $out);
	if($ret eq -1) { return -1; }
	else { return 1; }
}

sub gen_network_sysid
{
	my $self = shift @_;
	my $client_id = $self->{client}->{client_id};
	my ($ret, $out);
	if(!$client_id) {
        return "network_interface=primary {protocol_ipv6=no}\n";
    }
	my $sql = "SELECT * FROM as_boot_config 
		WHERE client_id = '$client_id'";
	my $ip = SCSDB::getResultHash($sql);
	if(!$ip || !$ip->{hostname} || !$ip->{ip}) {
        return "network_interface=primary {protocol_ipv6=no}\n";
	} 
	$out = "network_interface=primary ";
	$out .= "{hostname=$ip->{hostname} ";
	$out .= "ip_address=$ip->{ip} ";
	if($ip->{netmask}) { $out .= "netmask=$ip->{netmask} "; }
	else { $out .= "netmask=255.255.255.0 "; }
	if($ip->{gateway}) { $out .= "default_route=$ip->{gateway} "; }
	else { $out .= "default_route=none "; }
	if($ip->{ipv6} && $ip->{ipv6} =~ /^(y|true|on)/i) {
		$out .= "protocol_ipv6=yes}";
	} else { $out .= "protocol_ipv6=no}"; }
	$out .= "\n";
	return $out;
}

sub get_name_service
{
	my $self = shift @_;
	my $client_id = $self->{client}->{client_id};
	my ($ret, $out);
	if(!$client_id) { return -1; }
	my $sql = "SELECT * FROM as_boot_config 
		WHERE client_id = '$client_id'";
	my $ip = SCSDB::getResultHash($sql);
	if($ip->{nameserver}) {
        	$out = "name_service=DNS { ";
		if($ip->{domain}) {
			$out .= "domain_name=$ip->{domain} ";
		}
		$out .= "name_server=$ip->{nameserver} ";
		if($ip->{domain}) {
			$out .= "search=$ip->{domain} ";
		}
		$out .= "}\n";
	} elsif($self->get_option_value('enable_ldap') =~ /^(y|on|t)/i) {
		$out = "name_service=LDAP {";
		$ret = $self->get_option_value('ldap_basedn');
		if($ret eq -1) { return -1; }
		$out .= "domain_name=$ret profile=default";
		$ret = $self->get_option_value('ldap_server');
		if($ret eq -1) { return -1; }
		$out .= " profile_server=$ret}\n";
	} elsif($self->get_option_value('enable_nis') =~ /^(y|on|t)/i &&
		$cfg->is_ipaddr($self->get_option_value('nis_server')) ne 1) {
		# if nis_server is an ip address fail out
		#name_service=NIS {domain_name=west.arp.com name_server=timber(129.221.2.1)}
		$out = "name_service=NIS {";
		$ret = $self->get_option_value('nis_domain');
		if($ret eq -1) { return -1; }
		$out .= "domain_name=$ret";
		$ret = $self->get_option_value('nis_server');
		if($ret eq -1) { return -1; }
		$out .= " name_server=$ret}\n";
	} else { return -1; }
	
	return $out;
}
1;
